@@ -13,12 +13,13 @@ getTreeInfo <- function(object, which.tree=1) {
                     object$forest$splitType[,k],
                     object$forest$xbestsplit[,k],
                     object$forest$nodestatus[,k],
+                    object$forest$nodedepth[,k],
                     object$forest$nodepred[,k])[1:object$forest$ndbigtree[k],]
   } 
   
   dimnames(tree) <- list(1:nrow(tree), c("left daughter", "right daughter",
                                          "split segment","split type", "split point",
-                                         "status", "prediction"))
+                                         "status", "depth","prediction"))
   out <- list(segment.length=object$segment.length[k],target=object$target[k],
 				target.type=object$target.type[k],tree=tree)
   
